@@ -45,7 +45,7 @@ exports['routeHandler - Simple testing'] = function(test) {
 
     routeHandler(request, response);
 
-    var data = JSON.parse(response._getData());
+    var data = response._getJSONData();
 
     test.equal('Bob Dog', data.name);
     test.equal(42, data.age);
