@@ -75,6 +75,9 @@ function createRequest(options) {
     mockRequest.files = options.files ? options.files : {};
     mockRequest.socket = options.socket ? options.socket : {};
 
+    mockRequest.ip = options.ip || '127.0.0.1';
+    mockRequest.ips = [mockRequest.ip];
+
     //parse query string from url to object
     if (Object.keys(mockRequest.query).length === 0) {
         mockRequest.query = require('querystring').parse(mockRequest.url.split('?')[1]);
@@ -123,6 +126,7 @@ function createRequest(options) {
      */
 
     mockRequest.get =
+    mockRequest.getHeader =
     mockRequest.header = function(name) {
         name = name.toLowerCase();
         switch (name) {
@@ -478,7 +482,7 @@ function createRequest(options) {
         mockRequest.body[key] = value;
     };
 
-    
+
     /**
      * Function: send
      *
@@ -489,7 +493,7 @@ function createRequest(options) {
      *   data - string, array, object, number, buffer
      */
     mockRequest.send = function(data) {
-        
+
         if(Buffer.isBuffer(data)){
             this.emit('data', data);
         }else if(typeof data === 'object' || typeof data === 'number'){
@@ -500,6 +504,23 @@ function createRequest(options) {
         this.emit('end');
     };
 
+    /**
+     * Function: hostname
+     *
+     * If Hostname is not set explicitly, then derive it from the Host header without port information
+     *
+     */
+    if (!mockRequest.hostname) {
+        mockRequest.hostname = (function() {
+            if (!mockRequest.headers.host) {
+                return '';
+            }
+
+            var hostname = mockRequest.headers.host.split(':')[0].split('.');
+            return hostname.join('.');
+        }());
+    }
+
     /**
      * Function: subdomains
      *
@@ -516,7 +537,7 @@ function createRequest(options) {
 
         return subdomains.slice(offset);
     }());
-    
+
     return mockRequest;
 }
 
