@@ -30,6 +30,8 @@ var EventEmitter = require('./mockEventEmitter');
 var mime = require('mime');
 var http = require('./node/http');
 var utils = require('./utils');
+var path = require('path');
+var contentDisposition = require('content-disposition');
 
 function createResponse(options) {
 
@@ -122,7 +124,7 @@ function createResponse(options) {
             // We return without updating since in real life it's just possible the double call didn't
             // completely corrupt the response (for example not using chunked encoding due to HTTP/1.0 client)
             // and in this case the client will see the _original_ headers.
-            return;
+            return this;
         }
 
         mockResponse.statusCode = statusCode;
@@ -144,6 +146,7 @@ function createResponse(options) {
             Object.assign(mockResponse._headers, utils.convertKeysToLowerCase(headers));
         }
 
+        return this;
     };
 
     /**
@@ -464,6 +467,28 @@ function createResponse(options) {
         return mockResponse.setHeader('Vary', values.join(', '));
     };
 
+    /**
+     * Set _Content-Disposition_ header to _attachment_ with optional `filename`.
+     * 
+     * Example:
+     * 
+     *      res.attachment('download.csv')
+     *
+     * @param {String} filename
+     * @return {ServerResponse}
+     * @api public
+     */
+
+    mockResponse.attachment = function attachment(filename) {
+        if (filename) {
+            mockResponse.type(path.extname(filename));
+        }
+    
+        mockResponse.set('Content-Disposition', contentDisposition(filename));
+    
+        return this;
+    };
+
     /**
      * Append additional header `field` with value `val`.
      *
