@@ -62,6 +62,8 @@ describe('mockRequest', function() {
         expect(request.body).to.deep.equal({});
         expect(request.query).to.deep.equal({});
         expect(request.files).to.deep.equal({});
+        expect(request.ip).to.equal('127.0.0.1');
+        expect(request.ips).to.deep.equal([request.ip]);
       });
 
     });
@@ -210,8 +212,10 @@ describe('mockRequest', function() {
         request = mockRequest.createRequest(options);
         expect(request.header('KEY1')).to.equal('value1');
         expect(request.get('KEY1')).to.equal('value1');
+        expect(request.getHeader('KEY1')).to.equal('value1');
         expect(request.header('KEY2')).to.equal('value2');
         expect(request.get('KEY2')).to.equal('value2');
+        expect(request.getHeader('KEY2')).to.equal('value2');
       });
 
       it('should set .body to options.body', function() {
@@ -269,6 +273,24 @@ describe('mockRequest', function() {
         expect(request.mySampleProp).to.equal('la LA LA');
       });
 
+      it('should set .ip to options.ip', function() {
+        var options = {
+          ip: '192.168.1.1'
+        };
+
+        request = mockRequest.createRequest(options);
+        expect(request.ip).to.equal(options.ip);
+      });
+
+      it('should set .ips to [options.ip]', function() {
+        var options = {
+          ip: '192.168.1.1'
+        };
+
+        request = mockRequest.createRequest(options);
+        expect(request.ips).to.deep.equal([options.ip]);
+      });
+
     });
 
   });
@@ -289,6 +311,7 @@ describe('mockRequest', function() {
       request = mockRequest.createRequest(options);
       expect(request.get('key')).to.equal('value');
       expect(request.header('key')).to.equal('value');
+      expect(request.getHeader('key')).to.equal('value');
     });
 
     it('should return referer, when request as referrer', function() {
@@ -301,6 +324,7 @@ describe('mockRequest', function() {
       request = mockRequest.createRequest(options);
       expect(request.get('referrer')).to.equal('value');
       expect(request.header('referrer')).to.equal('value');
+      expect(request.getHeader('referrer')).to.equal('value');
     });
 
     it('should return referrer, when request as referer', function() {
@@ -313,12 +337,14 @@ describe('mockRequest', function() {
       request = mockRequest.createRequest(options);
       expect(request.get('referer')).to.equal('value');
       expect(request.header('referer')).to.equal('value');
+      expect(request.getHeader('referer')).to.equal('value');
     });
 
     it('should not return header, when not set', function() {
       request = mockRequest.createRequest();
       expect(request.get('key')).to.not.exist;
       expect(request.header('key')).to.not.exist;
+      expect(request.getHeader('key')).to.not.exist;
     });
 
   });
@@ -460,7 +486,7 @@ describe('mockRequest', function() {
       request = mockRequest.createRequest();
       expect(request.range()).to.be.undefined;
     });
-    
+
     var tests = [
       {
         // Unsatisfiable
@@ -685,6 +711,7 @@ describe('mockRequest', function() {
         request._setHeadersVariable('key', 'value');
         expect(request.get('key')).to.equal('value');
         expect(request.header('key')).to.equal('value');
+        expect(request.getHeader('key')).to.equal('value');
       });
 
       it('should throw an error, when called with missing arguments', function () {
@@ -881,6 +908,58 @@ describe('mockRequest', function() {
 
     });
 
+    describe('.hostname', function() {
+
+      it('should return the host\'s main domain', function() {
+        var options = {
+          headers: {
+            host: 'tobi.ferrets.example.com:5000'
+          }
+        };
+        request = mockRequest.createRequest(options);
+        expect(request.hostname).to.equal('tobi.ferrets.example.com');
+
+        options.headers.host = 'tobi.ferrets.example.com';
+        request = mockRequest.createRequest(options);
+        expect(request.hostname).to.equal('tobi.ferrets.example.com');
+
+        options.headers.host = 'example.com';
+        request = mockRequest.createRequest(options);
+        expect(request.hostname).to.equal('example.com');
+
+        options.headers.host = 'example.com:8443';
+        request = mockRequest.createRequest(options);
+        expect(request.hostname).to.equal('example.com');
+
+        options.headers.host = 'localhost:3000';
+        request = mockRequest.createRequest(options);
+        expect(request.hostname).to.equal('localhost');
+
+      });
+
+      it('should return an empty string', function () {
+        var options = {
+          headers: {
+            key1: 'key1'
+          }
+        };
+        request = mockRequest.createRequest(options);
+        expect(request.hostname).to.equal('');
+      });
+
+      it('should return an predefined hostname', function () {
+        var options = {
+          hostname: 'predefined.host.com',
+          headers: {
+            host: 'other.host'
+          }
+        };
+        request = mockRequest.createRequest(options);
+        expect(request.hostname).to.equal('predefined.host.com');
+      });
+
+    });
+
     describe('.subdomains', function() {
 
       it('should returns the host subdomains', function() {
